CommandEncoder

Struct CommandEncoder 

pub struct CommandEncoder;
Serializes a command packet into bytes for transmission.

Implementations

Source

impl CommandEncoder

pub fn encode_command_into( buffer: &mut Vec<u8>, command: &ProtocolCommand, ) -> Result<()>

Encodes a single command into the provided buffer (appends bytes).

pub fn encode_packet_into( buffer: &mut Vec<u8>, packet: &CommandPacket, ) -> Result<()>

Encodes a command packet into the provided buffer (appends bytes) without intermediate allocations per command.

pub fn encode_command(command: &ProtocolCommand) -> Result<Vec<u8>>

Encodes a single command into a byte vector

pub fn encode_packet(packet: &CommandPacket) -> Result<Vec<u8>>

Encodes a command packet with multiple commands