CongestionControl

Struct CongestionControl 

pub struct CongestionControl { /* private fields */ }
Congestion control and RTT tracking with dynamic throttle.

Implementations

Source

impl CongestionControl

pub fn new(rtt_alpha: f32, rtt_beta: f32) -> Self

Creates a new congestion control instance.

pub fn enable_advanced_throttling( &mut self, scale: u32, acceleration: u32, deceleration: u32, interval_ms: u32, )

Enables advanced throttling with custom parameters.

pub fn update_rtt(&mut self, sample: Duration)

Updates RTT measurement with a new sample. Uses exponential weighted moving average (EWMA).

pub fn rtt(&self) -> Duration

Returns the current smoothed RTT.

pub fn rtt_variance(&self) -> Duration

Returns the RTT variance.

pub fn rto(&self) -> Duration

Returns the retransmission timeout (RTO) based on RTT. Uses the standard RTO = RTT + 4 * variance formula.

pub fn record_loss(&mut self)

Records a packet loss event.

pub fn record_sent(&mut self)

Records a packet send event.

pub fn loss_rate(&self) -> f32

Returns the packet loss rate (0.0 to 1.0).

pub fn update_throttle(&mut self, now: Instant) -> bool

Updates the dynamic throttle based on current network conditions. Returns true if throttle was updated.

pub fn should_drop_unreliable(&self) -> bool

Returns whether an unreliable packet should be dropped based on throttle. Uses throttle as drop probability.

pub fn throttle(&self) -> f32

Returns the current throttle value.

pub fn packet_throttle(&self) -> u32

Returns the current packet throttle value (0 to throttle_scale).

pub fn throttle_scale(&self) -> u32

Returns the throttle scale.

pub fn is_advanced_throttling_enabled(&self) -> bool

Returns whether advanced throttling is enabled.

pub fn set_throttle_range(&mut self, min: f32, max: f32)

Sets the throttle range.

pub fn configure_throttle( &mut self, interval_ms: u32, acceleration: u32, deceleration: u32, )

Configures throttle parameters dynamically (for ThrottleConfigure command).

pub fn reset_stats(&mut self)

Resets all statistics.