pub struct IncomingPackets { /* private fields */ }Expand description
Collection of incoming packets (0, 1, or many) with their types. Used by command-based packet processing to return variable numbers of packets.
Implementations
Sourceimpl IncomingPackets
impl IncomingPackets
Sourcepub fn one(packet: Packet, packet_type: PacketType) -> Self
pub fn one(packet: Packet, packet_type: PacketType) -> Self
Creates a collection with a single packet and type.
Sourcepub fn many(vec: VecDeque<(Packet, PacketType)>) -> Self
pub fn many(vec: VecDeque<(Packet, PacketType)>) -> Self
Creates a collection with multiple packets.